@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #    OpaL Perl Modules
-#    Copyright (C) 2000,2007  Ola Lundqvist <ola@opalsys.net>
-#    $Id: manipulate.pm 2527 2007-12-06 19:57:04Z ola $
+#    Copyright (C) 2000,2007-2008  Ola Lundqvist <ola@inguza.com>
+#
 #    For full COPYRIGHT notice see the COPYING document.
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 #
 #
 #    For more information take a look at the official homepage at:
-#      http://opalsys.net/software/opalmod
+#      http://inguza.com/software/opalmod
 #    or contact the author at:
-#      ola@opalsys.net
+#      ola@inguza.com
 #
 
 package OpaL::manipulate;
@@ -146,7 +146,7 @@ The errorlevel is optional.
 
 =head1 AUTHOR
 
-Ola Lundqvist <ola@opalsys.net>
+Ola Lundqvist <ola@inguza.com>
 
 =head1 REQUIRES
 
@@ -172,7 +172,7 @@ perl(1)
 #		eg. perl -pi -e script file.
 # Arguments:	$file, $script, $message [, $level ]
 # Uses:		system, perl, cmdaction
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-04	Written
 #		2000-05-13	Better argument definition.
 #		2000-06-29	Added argument definition.
@@ -191,7 +191,7 @@ sub perlmodifyadvanced {#($$$;$) {
 #		eg. perl -pi -e script file. And makes some fixes before.
 # Arguments:	$file, $script, $message [, $level ]
 # Uses:		system, perl, cmdaction
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-04	Written
 #		2000-05-13	Better argument definition.
 #		2000-06-04	Added some fixes to make it more secure.
@@ -211,7 +211,7 @@ sub perlmodify {#($$$;$) {
 #		eg. perl -pi -e script file.
 # Arguments:	$file, $find, $text, $message [, $level ]
 # Uses:		perlmodify
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-05-04
 #		2000-06-04	Fixed so that insert after do not make
 #				repeated inserts. (never ever)
