@@ -1,7 +1,7 @@
 #!/usr/bin/perl
 #    OpaL Perl Modules
-#    Copyright (C) 2000,2007  Ola Lundqvist <ola@opalsys.net>
-#    $Id: where.pm 2527 2007-12-06 19:57:04Z ola $
+#    Copyright (C) 2000,2007-2008  Ola Lundqvist <ola@inguza.com>
+#
 #    For full COPYRIGHT notice see the COPYING document.
 #
 #    This program is free software; you can redistribute it and/or modify
@@ -20,9 +20,9 @@
 #
 #
 #    For more information take a look at the official homepage at:
-#      http://opalsys.net/software/opalmod
+#      http://inguza.com/software/opalmod
 #    or contact the author at:
-#      ola@opalsys.net
+#      ola@inguza.com
 #
 
 package OpaL::where;
@@ -110,7 +110,7 @@ USAGE:
 
 =head1 AUTHOR
 
-Ola Lundqvist <ola@opalsys.net>
+Ola Lundqvist <ola@inguza.com>
 
 =head1 SEE ALSO
 
@@ -128,7 +128,7 @@ perl(1), which(1).
 #		file if found, undef else.
 # Arguments:	A program to search for.
 # Requres:	$ENV{'PATH'}
-# Author:	Ola Lundqvist <ola@opalsys.net>
+# Author:	Ola Lundqvist <ola@inguza.com>
 # Date:		2000-07-09	Wrote it!
 ###############################################################################
 sub which {
